'''OpenGL extension MESA.agp_offset

This module customises the behaviour of the 
OpenGL.raw.GLX.MESA.agp_offset to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extensions provides a way to convert pointers in an AGP memory
	region into byte offsets into the AGP aperture.
	Note, this extension depends on GLX_NV_vertex_array_range, for which
	no real specification exists.  See GL_NV_vertex_array_range for more
	information.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/MESA/agp_offset.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLX import _types, _glgets
from OpenGL.raw.GLX.MESA.agp_offset import *
from OpenGL.raw.GLX.MESA.agp_offset import _EXTENSION_NAME

def glInitAgpOffsetMESA():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_AMD_draw_buffers_blend'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_AMD_draw_buffers_blend',error_checker=_errors._error_checker)

@_f
@_p.types(None,_cs.GLuint,_cs.GLenum)
def glBlendEquationIndexedAMD(buf,mode):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLenum)
def glBlendEquationSeparateIndexedAMD(buf,modeRGB,modeAlpha):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLenum)
def glBlendFuncIndexedAMD(buf,src,dst):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLenum,_cs.GLenum,_cs.GLenum)
def glBlendFuncSeparateIndexedAMD(buf,srcRGB,dstRGB,srcAlpha,dstAlpha):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLX import _types as _cs
# End users want this...
from OpenGL.raw.GLX._types import *
from OpenGL.raw.GLX import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLX_NV_swap_group'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLX,'GLX_NV_swap_group',error_checker=_errors._error_checker)

@_f
@_p.types(_cs.Bool,ctypes.POINTER(_cs.Display),_cs.GLuint,_cs.GLuint)
def glXBindSwapBarrierNV(dpy,group,barrier):pass
@_f
@_p.types(_cs.Bool,ctypes.POINTER(_cs.Display),_cs.GLXDrawable,_cs.GLuint)
def glXJoinSwapGroupNV(dpy,drawable,group):pass
@_f
@_p.types(_cs.Bool,ctypes.POINTER(_cs.Display),_cs.c_int,arrays.GLuintArray)
def glXQueryFrameCountNV(dpy,screen,count):pass
@_f
@_p.types(_cs.Bool,ctypes.POINTER(_cs.Display),_cs.c_int,arrays.GLuintArray,arrays.GLuintArray)
def glXQueryMaxSwapGroupsNV(dpy,screen,maxGroups,maxBarriers):pass
@_f
@_p.types(_cs.Bool,ctypes.POINTER(_cs.Display),_cs.GLXDrawable,arrays.GLuintArray,arrays.GLuintArray)
def glXQuerySwapGroupNV(dpy,drawable,group,barrier):pass
@_f
@_p.types(_cs.Bool,ctypes.POINTER(_cs.Display),_cs.c_int)
def glXResetFrameCountNV(dpy,screen):pass
